==> envinject-1.42-sources.jar: org/jenkinsci/plugins/envinject/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.envinject;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Setup a build environment
     * 
     */
    public static String envinject_set_displayName() {
        return holder.format("envinject.set.displayName");
    }

    /**
     * Setup a build environment
     * 
     */
    public static Localizable _envinject_set_displayName() {
        return new Localizable(holder, "envinject.set.displayName");
    }

    /**
     * Prepare jobs environment
     * 
     */
    public static String envinject_nodeProperty_displayName() {
        return holder.format("envinject.nodeProperty.displayName");
    }

    /**
     * Prepare jobs environment
     * 
     */
    public static Localizable _envinject_nodeProperty_displayName() {
        return new Localizable(holder, "envinject.nodeProperty.displayName");
    }

    /**
     * Inject environment variables to the build process
     * 
     */
    public static String envinject_wrapper_displayName() {
        return holder.format("envinject.wrapper.displayName");
    }

    /**
     * Inject environment variables to the build process
     * 
     */
    public static Localizable _envinject_wrapper_displayName() {
        return new Localizable(holder, "envinject.wrapper.displayName");
    }

    /**
     * Inject environment variables
     * 
     */
    public static String envinject_addVars_displayName() {
        return holder.format("envinject.addVars.displayName");
    }

    /**
     * Inject environment variables
     * 
     */
    public static Localizable _envinject_addVars_displayName() {
        return new Localizable(holder, "envinject.addVars.displayName");
    }

}

==> envinject-1.52-sources.jar: org/jenkinsci/plugins/envinject/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.envinject;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Setup a build environment
     * 
     */
    public static String envinject_set_displayName() {
        return holder.format("envinject.set.displayName");
    }

    /**
     * Setup a build environment
     * 
     */
    public static Localizable _envinject_set_displayName() {
        return new Localizable(holder, "envinject.set.displayName");
    }

    /**
     * Prepare jobs environment
     * 
     */
    public static String envinject_nodeProperty_displayName() {
        return holder.format("envinject.nodeProperty.displayName");
    }

    /**
     * Prepare jobs environment
     * 
     */
    public static Localizable _envinject_nodeProperty_displayName() {
        return new Localizable(holder, "envinject.nodeProperty.displayName");
    }

    /**
     * Inject environment variables to the build process
     * 
     */
    public static String envinject_wrapper_displayName() {
        return holder.format("envinject.wrapper.displayName");
    }

    /**
     * Inject environment variables to the build process
     * 
     */
    public static Localizable _envinject_wrapper_displayName() {
        return new Localizable(holder, "envinject.wrapper.displayName");
    }

    /**
     * Inject passwords to the build as environment variables
     * 
     */
    public static String EnvInjectPasswordWrapper_DisplayName() {
        return holder.format("EnvInjectPasswordWrapper.DisplayName");
    }

    /**
     * Inject passwords to the build as environment variables
     * 
     */
    public static Localizable _EnvInjectPasswordWrapper_DisplayName() {
        return new Localizable(holder, "EnvInjectPasswordWrapper.DisplayName");
    }

    /**
     * Inject environment variables
     * 
     */
    public static String envinject_addVars_displayName() {
        return holder.format("envinject.addVars.displayName");
    }

    /**
     * Inject environment variables
     * 
     */
    public static Localizable _envinject_addVars_displayName() {
        return new Localizable(holder, "envinject.addVars.displayName");
    }

}
